# Melody

Melody is a lightweight parameter search and optimisation tool
originally designed to support searching and optimising over the
performance landscape of software. In particular, it is being designed
to support code composition options (loop ordering, loop fusion etc),
code compilation and link options (compilers and compiler flags) and
code configuration options (tunable parameters such as a cut off
radius, or preconditioner). However Melody has been written in a
relatively generic way so can be used to search over, or optimise any
search space.

Melody takes its name from the fact that optimisation is often called
tuning and most good tunes rely on a great melody!

# Badges

[![Build Status](https://travis-ci.org/rupertford/melody.svg?branch=master)](https://travis-ci.org/rupertford/melody)
[![Coverage Status](https://coveralls.io/repos/github/rupertford/melody/badge.svg?branch=master)](https://coveralls.io/github/rupertford/melody?branch=master)
[![Code Health](https://landscape.io/github/rupertford/melody/master/landscape.svg?style=flat)](https://landscape.io/github/rupertford/melody/master)
[![Documentation Status](https://readthedocs.org/projects/melody/badge/?version=latest)](http://melody.readthedocs.io/en/latest/?badge=documentation)

# Licensing

Melody is available under a BSD 3-clause license. A copy of this
license is provided when Melody is downloaded and installed.

# Installation

Melody can be installed and uninstalled using pip.

```
> sudo pip install melody
> sudo pip uninstall melody
```

# Documentation

Documentation is available here:

http://melody.readthedocs.io/en/documentation
